******
How to
******

This is a collection of small tutorials explaining how to manipulate Antidote in different scenarios.


.. toctree::
    :maxdepth: 2

    how_to/annotated_type_hints
    how_to/test
    how_to/debug
